summaryrefslogtreecommitdiffstats
path: root/src/mencoderCmdGen.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/mencoderCmdGen.cpp')
-rw-r--r--src/mencoderCmdGen.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mencoderCmdGen.cpp b/src/mencoderCmdGen.cpp
index 744e527..bd9addd 100644
--- a/src/mencoderCmdGen.cpp
+++ b/src/mencoderCmdGen.cpp
@@ -24,14 +24,14 @@
#include "kpushbutton.h"
/*
* Constructs a MyDialog1 as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*
* The dialog will by default be modeless, unless you set 'modal' to
* TRUE to construct a modal dialog.
*/
-MyDialog1::MyDialog1( TQWidget* tqparent, const char* name, bool modal, WFlags fl )
- : TQDialog( tqparent, name, modal, fl )
+MyDialog1::MyDialog1( TQWidget* parent, const char* name, bool modal, WFlags fl )
+ : TQDialog( parent, name, modal, fl )
{
if ( !name )
setName( "MyDialog1" );
@@ -24,14 +24,14 @@
#include "kpushbutton.h"
/*
- * Constructs a MyDialog1 as a child of 'tqparent', with the
+ * Constructs a MyDialog1 as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*